//
//  SOMAMillennialMediaPlugin.m
//  SomaClientSideMediation
//
//  Created by Aman Shaikh on 12.10.15.
//  Copyright © 2015 Smaato Inc. All rights reserved.
//

#import "SOMAMillennialMediaPlugin.h"

@implementation SOMAMillennialMediaPlugin
- (void)load{
	static dispatch_once_t onceToken;
	dispatch_once(&onceToken, ^{
		[MMSDK setLogLevel:MMLogLevelDebug];
		[[MMSDK sharedInstance] initializeWithSettings:nil withUserSettings:nil];
	});
	
	if (self.network.adunitid == nil) {
		[self adLoadFailedWithMessage:@"AdUnit value should be a JSON objet e.g. {\"adunitid\": \"ca-app-pub-3940256099942544/6300978111\"}"];
		return;
	}
	
	
	if (self.isInterstitial) {
		[self loadInterstitial];
		return;
	}
	
	MMInlineAdSize adSize = (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPhone) ? MMInlineAdSizeBanner :MMInlineAdSizeLeaderboard;
	if (self.adDimension == SOMAAdDimensionMedRect) {
		adSize = MMInlineAdSizeMediumRectangle;
	}
	
	self.inlineAd = [[MMInlineAd alloc] initWithPlacementId:self.network.adunitid adSize:adSize];
	self.inlineAd.delegate = self;
	[self.inlineAd request:nil];
}
- (void)dealloc{
	NSLog(@"Deallocated: %@", NSStringFromClass([self class]));
}

- (void)loadInterstitial{
	self.interstitialAd = [[MMInterstitialAd alloc] initWithPlacementId:self.network.adunitid];
	self.interstitialAd.delegate = self;
	self.interstitialAd.modalTransitionStyle = UIModalTransitionStyleCoverVertical;
	[self.interstitialAd load:nil];
}

- (void)presentInterstitial{
	 [self.interstitialAd showFromViewController:[self rootViewController]];
}


#pragma mark -
#pragma mark - MMInlineDelegate
#pragma mark -
- (void)inlineAdRequestDidSucceed:(MMInlineAd *)ad {
	NSLog(@"Inline request succeeded.");
	[self adLoadedWithView:ad.view];
}

- (void)inlineAd:(MMInlineAd *)ad requestDidFailWithError:(NSError *)error {
	NSLog(@"Inline ad failed: %@.", error);
	[self adLoadFailedWithError:error];
}

- (void)inlineAdContentTapped:(MMInlineAd *)ad {
	NSLog(@"Inline ad tapped.");
}

- (void)inlineAd:(MMInlineAd *)ad willResizeTo:(CGRect)frame isClosing:(BOOL)isClosingResize {
	NSLog(@"Inline ad is %@ and will resize to frame %@.", isClosingResize ? @"closing" : @"resizing", NSStringFromCGRect(frame));
}

- (void)inlineAd:(MMInlineAd *)ad didResizeTo:(CGRect)frame isClosing:(BOOL)isClosingResize {
	NSLog(@"Inline ad is %@ and did resize to frame %@.", isClosingResize ? @"closing" : @"resizing", NSStringFromCGRect(frame));
}

- (void)inlineAdWillPresentModal:(MMInlineAd *)ad {
	NSLog(@"Inline ad will present modal view.");
	[self adWillPresentFullscreen];
}

- (void)inlineAdDidPresentModal:(MMInlineAd *)ad {
	NSLog(@"Inline ad did present modal view.");
}

- (void)inlineAdWillCloseModal:(MMInlineAd *)ad {
	NSLog(@"Inline ad will close modal view.");
}

- (void)inlineAdDidCloseModal:(MMInlineAd *)ad {
	[self adDidDismissFullscreen];
}

- (void)inlineAdWillLeaveApplication:(MMInlineAd *)ad {
	[self adWillLeaveApplication];
}

- (UIViewController *)viewControllerForPresentingModalView {
	return [self rootViewController];
}

#pragma mark - Interstitial Delegate

- (void)interstitialAdLoadDidSucceed:(MMInterstitialAd *)ad {
	[self adLoadedWithView:nil];
}

- (void)interstitialAd:(MMInterstitialAd *)ad loadDidFailWithError:(NSError *)error {
	NSLog(@"Interstitial load failed: %@.", error);
	[self adLoadFailedWithError:error];
}

- (void)interstitialAdWillDisplay:(MMInterstitialAd *)ad {
	NSLog(@"Interstitial will display.");
	[self adWillPresentFullscreen];
}

- (void)interstitialAdDidDisplay:(MMInterstitialAd *)ad {
	NSLog(@"Interstitial did display.");
	
}

- (void)interstitialAdWillDismiss:(MMInterstitialAd *)ad {
	NSLog(@"Interstitial will dismiss.");
}

- (void)interstitialAdDidDismiss:(MMInterstitialAd *)ad {
	NSLog(@"Interstitial did dismiss.");
	[self adDidDismissFullscreen];
}

- (void)interstitialAdTapped:(MMInterstitialAd *)ad {
	NSLog(@"Interstitial tapped.");
}

- (void)interstitialAdWillLeaveApplication:(MMInterstitialAd *)ad {
	[self adWillLeaveApplication];
	NSLog(@"Interstitial ad will leave application.");
}
@end
